@@ -2,7 +2,7 @@ package Tinkerforge;
 
 # setting the module version
 use vars '$VERSION';
-our $VERSION = '2.1.23';
+our $VERSION = '2.1.24';
 
 =pod
 
@@ -14,15 +14,15 @@ Tinkerforge - Official Perl support for all Tinkerforge Bricks and Bricklets
 
 =head1 VERSION
 
-Version 2.1.23
+Version 2.1.24
 
 =head1 ABSTRACT
 
 The Tinkerforge Perl module provides official API support for all Tinkerforge
 Bricks and Bricklets. A comprehensive documentation for the Perl bindings can
 be found at,
-English: L<strict|http://www.tinkerforge.com/en/doc/Software/API_Bindings_Perl.html>
-German: L<strict|http://www.tinkerforge.com/de/doc/Software/API_Bindings_Perl.html>
+English: L<strict|https://www.tinkerforge.com/en/doc/Software/API_Bindings_Perl.html>
+German: L<strict|https://www.tinkerforge.com/de/doc/Software/API_Bindings_Perl.html>
 
 =cut
 
